Learn R Programming

fishdata (version 1.0.1)

adult_growth: Growth data of adult fish

Description

A dataset containing daily age and growth data for adult Galaxis maculatus.

Usage

adult_growth

Arguments

Format

A dataset containing 16795 rows and 4 variables

fish_code

Foreign key, matches to `adults`. Identifies the fish being measured.

period

a count of each otolith increment. Counts a day in the fishes life

position

the distance of the increment from the centre of the otolith

distance

the distance of the increment from the previous increment

Examples

Run this code
# NOT RUN {
data(adult_growth)

# }

Run the code above in your browser using DataLab