Learn R Programming

fishdata (version 1.0.1)

juvenile_growth: Growth data of juvenile fish

Description

A dataset containing daily growth data for juvenile Galaxis maculatus.

Usage

juvenile_growth

Arguments

Format

A dataset containing 87581 rows and 5 variables

fish_code

Foreign key, links with `juveniles`

otolith_code

Alternate key

period

a count of each otolith increment. Counts a day in the fishes life

position

the distance of the increment from the centre of the otolith

distance

the distance of the increment from the previous increment

Examples

Run this code
# NOT RUN {
data(juvenile_growth)
# }

Run the code above in your browser using DataLab