Learn R Programming

fishdata (version 1.0.1)

juvenile_metrics: Juvenile fish metrics data

Description

A dataset containing metrics data for juvenile Galaxis maculatus.

Usage

juvenile_metrics

Arguments

Format

A dataset containing 496 rows and 8 variables

fish_code

Foreign key (matches with `juveniles`)

standard_length

standard length of the fish (distance from posterior to caudal peduncle), cm

body_depth

body depth of the fish at its maximum point, cm

age

Age of fish when caught (days)

birthdate

Day fish hatched

growth_rate

Average daily growth of fish (mm/day)

growth_rate

Average daily growth of fish over first 10 days of life (mm/day)

growth_rate

Average daily growth of fish over last 10 days of life (mm/day)

Examples

Run this code
# NOT RUN {
data(juvenile_metrics)
# }

Run the code above in your browser using DataLab