powered by
A dataset containing daily age and growth data for adult Galaxis maculatus.
adult_growth
A dataset containing 16795 rows and 4 variables
Foreign key, matches to `adults`. Identifies the fish being measured.
a count of each otolith increment. Counts a day in the fishes life
the distance of the increment from the centre of the otolith
the distance of the increment from the previous increment
# NOT RUN { data(adult_growth) # }
Run the code above in your browser using DataLab