powered by
A dataset containing daily growth data for juvenile Galaxis maculatus.
juvenile_growth
A dataset containing 87581 rows and 5 variables
Foreign key, links with `juveniles`
Alternate key
a count of each otolith increment. Counts a day in the fishes life
the distance of the increment from the centre of the otolith
the distance of the increment from the previous increment
# NOT RUN { data(juvenile_growth) # }
Run the code above in your browser using DataLab